==> haskell-http-client-tls-0.3.5.3-132-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.3.5.3
id: http-client-tls-0.3.5.3-IENmtIJRh8f8yM5X1HdjRQ
key: http-client-tls-0.3.5.3-IENmtIJRh8f8yM5X1HdjRQ
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.
category: Network
abi: a38bd99119ed4eae3623b8ab0a965e9b
exposed: True
exposed-modules:
    Network.HTTP.Client.TLS
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-tls-0.3.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-tls-0.3.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-client-tls-0.3.5.3
hs-libraries: HShttp-client-tls-0.3.5.3-IENmtIJRh8f8yM5X1HdjRQ
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    connection-0.3.0-JBeF4J4TqMK9gdc3DSPqQ containers-0.6.0.1
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    exceptions-0.10.2-F5iQJa9RoWHAiWKkKHwe3
    http-client-0.6.4-1ZFfhHOFZM7LvAxodh0J00
    http-types-0.12.3-4mvqCFA58Pd9Ot84cA11d5
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    network-2.8.0.0-HTKosw7lwpaCVnkz1nc19d
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK text-1.2.3.1
    tls-1.4.1-19glv3cmc0cJ8jILL90nTj transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.5.3-135-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.3.5.3
id: http-client-tls-0.3.5.3-ZsziWEYBPOBejZdpVEY1K
key: http-client-tls-0.3.5.3-ZsziWEYBPOBejZdpVEY1K
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.
category: Network
abi: 6d92414eb6cbf9c383e956d867267156
exposed: True
exposed-modules:
    Network.HTTP.Client.TLS
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-tls-0.3.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-tls-0.3.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-client-tls-0.3.5.3
hs-libraries: HShttp-client-tls-0.3.5.3-ZsziWEYBPOBejZdpVEY1K
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    connection-0.3.0-FYMWS6P5X5SD5XTdK8sLvC containers-0.6.0.1
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    exceptions-0.10.2-HDaOvlvHbPR767FjhdL1tt
    http-client-0.6.4-3teZlNPLWgND063m5LILnU
    http-types-0.12.3-9Oghevaq5FtBD8UlWmZNzU
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    network-2.8.0.0-1DkaUVvVIsp8sj7KmlE9xl
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK text-1.2.3.1
    tls-1.4.1-EltBU3ujLDRBGrQ6gjYApc transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
